# Installation Problems

General advice:

* search the contents of this page and troubleshooting pages referenced
* search the issue tracker including closed issues, maybe someone else encountered the same issue before you
* search the discuss mailing list, maybe someone else encountered the same issue before you
* file and issue or ask on the discuss mailing list, **make sure to add as much relevant details as possible**

## log2timeline failing dependencies check

When I run log2timeline it warns that certain dependencies are missing e.g.
```
Checking availability and versions of plaso dependencies.
[FAILURE]       missing: pyewf.
```

**TODO: add more text**

## Mac OS-X 

See: [Troubleshooting Mac OS X](Troubleshooting-MacOS.md)

## Windows

See: [Troubleshooting Windows](Troubleshooting-Windows.md)
